{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#bwa_mem.cwl",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/bwa-picard:broad"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 14000,
                    "coresMin": 16
                }
            ],
            "baseCommand": [
                "java",
                "-Xms5000m",
                "-jar",
                "/picard.jar"
            ],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "SamToFastq INPUT=$(inputs.input_bam.path) FASTQ=/dev/stdout INTERLEAVE=true NON_PF=true | bwa mem -K 100000000 -p -v 3 -t 16 -Y $(inputs.indexed_reference_fasta.path) - | java -Dsamjdk.compression_level=2 -Xms4000m -jar /picard.jar MergeBamAlignment VALIDATION_STRINGENCY=SILENT EXPECTED_ORIENTATIONS=FR ATTRIBUTES_TO_RETAIN=X0 ATTRIBUTES_TO_REMOVE=NM ATTRIBUTES_TO_REMOVE=MD ALIGNED_BAM=/dev/stdin UNMAPPED_BAM=$(inputs.input_bam.path) OUTPUT=$(inputs.input_bam.nameroot).aligned.unsorted.bam REFERENCE_SEQUENCE=$(inputs.indexed_reference_fasta.path) PAIRED_RUN=true SORT_ORDER='unsorted' IS_BISULFITE_SEQUENCE=false ALIGNED_READS_ONLY=false CLIP_ADAPTERS=false MAX_RECORDS_IN_RAM=2000000 ADD_MATE_CIGAR=true MAX_INSERTIONS_OR_DELETIONS=-1 PRIMARY_ALIGNMENT_STRATEGY=MostDistant PROGRAM_RECORD_ID='bwamem' PROGRAM_GROUP_NAME='bwamem' PROGRAM_GROUP_VERSION='0.7.15-r1140' PROGRAM_GROUP_COMMAND_LINE='bwa mem -K 100000000 -p -v 3 -t 16 -Y $(inputs.indexed_reference_fasta.basename)' ALIGNER_PROPER_PAIR_FLAGS=true UNMAP_CONTAMINANT_READS=true UNMAPPED_READ_STRATEGY=COPY_TO_TAG"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".64.amb",
                        ".64.ann",
                        ".64.bwt",
                        ".64.pac",
                        ".64.sa",
                        ".64.alt",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#bwa_mem.cwl/bwa_mem/indexed_reference_fasta"
                },
                {
                    "type": "File",
                    "id": "#bwa_mem.cwl/bwa_mem/input_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bam"
                    },
                    "id": "#bwa_mem.cwl/bwa_mem/output"
                }
            ]
        },
        {
            "class": "ExpressionTool",
            "id": "#expression_checkcontamination.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#expression_checkcontamination.cwl/expression_checkcontamination/verifybamid_selfsm"
                }
            ],
            "outputs": [
                {
                    "type": "float",
                    "id": "#expression_checkcontamination.cwl/expression_checkcontamination/contamination"
                }
            ],
            "expression": "${ var lines=inputs.verifybamid_selfsm.contents.split('\\n'); for (var i=1; i<lines.length; i++){ var fields=lines[i].split('\\t'); if (fields.length != 19) {continue;} return {contamination: fields[6]/0.75}; } }"
        },
        {
            "class": "CommandLineTool",
            "id": "#gatk_applybqsr.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/gatk:4.beta.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4500
                }
            ],
            "baseCommand": [
                "/gatk-launch",
                "ApplyBQSR"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "--javaOptions \"-Xms3000m -XX:+PrintFlagsFinal -XX:+PrintGCTimeStamps -XX:+PrintGCDateStamps -XX:+PrintGCDetails -Xloggc:gc_log.log -XX:GCTimeLimit=50 -XX:GCHeapFreeLimit=10\" --createOutputBamMD5 --addOutputSAMProgramRecord -R $(inputs.reference.path) -I $(inputs.input_bam.path) --useOriginalQualities -O $(inputs.input_bam.nameroot).aligned.duplicates_marked.recalibrated.bam -bqsr $(inputs.bqsr_report.path) -SQQ 10 -SQQ 20 -SQQ 30 -L $(inputs.sequence_interval.path)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/bqsr_report"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/input_bam"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/reference"
                },
                {
                    "type": "File",
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/sequence_interval"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*bam"
                    },
                    "secondaryFiles": [
                        "^.bai",
                        ".md5"
                    ],
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/recalibrated_bam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#gatk_baserecalibrator.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/gatk:4.beta.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "baseCommand": [
                "/gatk-launch",
                "BaseRecalibrator"
            ],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "--javaOptions \"-Xms4000m -XX:GCTimeLimit=50 -XX:GCHeapFreeLimit=10 -XX:+PrintFlagsFinal -XX:+PrintGCTimeStamps -XX:+PrintGCDateStamps -XX:+PrintGCDetails -Xloggc:gc_log.log\" -R $(inputs.reference.path) -I $(inputs.input_bam.path) --useOriginalQualities -O $(inputs.input_bam.nameroot).recal_data.csv -L $(inputs.sequence_interval.path)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/input_bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-knownSites"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/knownsites"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/reference"
                },
                {
                    "type": "File",
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/sequence_interval"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.recal_data.csv"
                    },
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#gatk_gatherbqsrreports.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/gatk:4.beta.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "baseCommand": [
                "/gatk-launch",
                "GatherBQSRReports"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "--javaOptions \"-Xms3000m\" -O $(inputs.output_basename).GatherBqsrReports.recal_data.csv"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-I",
                            "separate": true
                        }
                    },
                    "id": "#gatk_gatherbqsrreports.cwl/gatk_gatherbqsrreports/input_brsq_reports"
                },
                {
                    "type": "string",
                    "id": "#gatk_gatherbqsrreports.cwl/gatk_gatherbqsrreports/output_basename"
                }
            ],
            "outputs": [
                {
                    "id": "#gatk_gatherbqsrreports.cwl/gatk_gatherbqsrreports/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.csv"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#gatk_haplotypecaller.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/gatk:4.beta.1-3.5"
                }
            ],
            "baseCommand": [
                "/gatk-launch",
                "--javaOptions",
                "-Xms2000m"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "PrintReads -I $(inputs.input_bam.path) --interval_padding 500 -L $(inputs.interval_list.path) -O local.sharded.bam && java -XX:GCTimeLimit=50 -XX:GCHeapFreeLimit=10 -Xms8000m -jar /GenomeAnalysisTK.jar -T HaplotypeCaller -R $(inputs.reference.path) -o $(inputs.input_bam.nameroot).vcf.gz -I local.sharded.bam -L $(inputs.interval_list.path) -ERC GVCF --max_alternate_alleles 3 -variant_index_parameter 128000 -variant_index_type LINEAR -contamination $(inputs.contamination) --read_filter OverclippedRead"
                }
            ],
            "inputs": [
                {
                    "type": "float",
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/contamination"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/input_bam"
                },
                {
                    "type": "File",
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#gatk_validategvcf.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/gatk:3.6-0-g89b7209"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 30000
                }
            ],
            "baseCommand": [
                "/usr/bin/java",
                "-Xms2000m",
                "-jar",
                "/GenomeAnalysisTK.jar"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "-T ValidateVariants -V $(inputs.input_vcf.path) -R $(inputs.reference.path) -L $(inputs.wgs_calling_interval_list.path) -gvcf --validationTypeToExclude ALLELES --dbsnp $(inputs.dbsnp_vcf.path)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".idx",
                    "id": "#gatk_validategvcf.cwl/gatk_validategvcf/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": ".tbi",
                    "id": "#gatk_validategvcf.cwl/gatk_validategvcf/input_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#gatk_validategvcf.cwl/gatk_validategvcf/reference"
                },
                {
                    "type": "File",
                    "id": "#gatk_validategvcf.cwl/gatk_validategvcf/wgs_calling_interval_list"
                }
            ],
            "outputs": []
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_calculatereadgroupchecksum.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.8.3"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "baseCommand": [
                "java",
                "-Xms2000m",
                "-jar",
                "/picard.jar",
                "CalculateReadGroupChecksum"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "INPUT=$(inputs.input_bam.path) OUTPUT=$(inputs.input_bam.nameroot).bam.read_group_md5"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#picard_calculatereadgroupchecksum.cwl/picard_calculatereadgroupchecksum/input_bam"
                }
            ],
            "outputs": [
                {
                    "id": "#picard_calculatereadgroupchecksum.cwl/picard_calculatereadgroupchecksum/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.md5"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_collectaggregationmetrics.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard-r:picard2.8.3-r3.3.3"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 10000
                }
            ],
            "baseCommand": [
                "java",
                "-Xms5000m",
                "-jar",
                "/picard.jar",
                "CollectMultipleMetrics"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "INPUT=$(inputs.input_bam.path) REFERENCE_SEQUENCE=$(inputs.reference.path) OUTPUT=$(inputs.input_bam.nameroot) ASSUME_SORTED=true PROGRAM=\"null\" PROGRAM=\"CollectAlignmentSummaryMetrics\"  PROGRAM=\"CollectInsertSizeMetrics\"  PROGRAM=\"CollectSequencingArtifactMetrics\"  PROGRAM=\"CollectGcBiasMetrics\"  PROGRAM=\"QualityScoreDistribution\"  METRIC_ACCUMULATION_LEVEL=\"null\"  METRIC_ACCUMULATION_LEVEL=\"SAMPLE\"  METRIC_ACCUMULATION_LEVEL=\"LIBRARY\""
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#picard_collectaggregationmetrics.cwl/picard_collectaggregationmetrics/input_bam"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#picard_collectaggregationmetrics.cwl/picard_collectaggregationmetrics/reference"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.nameroot).*"
                    },
                    "id": "#picard_collectaggregationmetrics.cwl/picard_collectaggregationmetrics/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_collectgvcfcallingmetrics.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 3000,
                    "coresMin": 16
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.8.3"
                }
            ],
            "baseCommand": [
                "java",
                "-Xms2000m",
                "-jar",
                "/picard.jar",
                "CollectVariantCallingMetrics"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "INPUT=$(inputs.input_vcf.path) OUTPUT=$(inputs.final_gvcf_base_name) DBSNP=$(inputs.dbsnp_vcf.path) SEQUENCE_DICTIONARY=$(inputs.reference_dict.path) TARGET_INTERVALS=$(inputs.wgs_evaluation_interval_list.path) GVCF_INPUT=true THREAD_COUNT=16"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/dbsnp_vcf"
                },
                {
                    "type": "string",
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/final_gvcf_base_name"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/input_vcf"
                },
                {
                    "type": "File",
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/reference_dict"
                },
                {
                    "type": "File",
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/wgs_evaluation_interval_list"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_metrics"
                    },
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_collectqualityyieldmetrics.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.8.3"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "baseCommand": [
                "java",
                "-Xms2000m",
                "-jar",
                "/picard.jar",
                "CollectQualityYieldMetrics"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "INPUT=$(inputs.input_bam.path) OQ=true OUTPUT=$(inputs.output_basename).$(inputs.input_bam.nameroot).unmapped.quality_yield_metrics"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#picard_collectqualityyieldmetrics.cwl/picard_collectqualityyieldmetrics/input_bam"
                },
                {
                    "type": "string",
                    "id": "#picard_collectqualityyieldmetrics.cwl/picard_collectqualityyieldmetrics/output_basename"
                }
            ],
            "outputs": [
                {
                    "id": "#picard_collectqualityyieldmetrics.cwl/picard_collectqualityyieldmetrics/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_basename).$(inputs.input_bam.nameroot).unmapped.quality_yield_metrics"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_collectreadgroupbamqualitymetrics.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard-r:picard2.8.3-r3.3.3"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "baseCommand": [
                "java",
                "-Xms5000m",
                "-jar",
                "/picard.jar",
                "CollectMultipleMetrics"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "INPUT=$(inputs.input_bam.path) REFERENCE_SEQUENCE=$(inputs.reference.path) OUTPUT=$(inputs.input_bam.nameroot) ASSUME_SORTED=true PROGRAM=\"null\" PROGRAM=\"CollectAlignmentSummaryMetrics\"  PROGRAM=\"CollectGcBiasMetrics\"  METRIC_ACCUMULATION_LEVEL=\"null\"  METRIC_ACCUMULATION_LEVEL=\"READ_GROUP\""
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#picard_collectreadgroupbamqualitymetrics.cwl/picard_collectreadgroupbamqualitymetrics/input_bam"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#picard_collectreadgroupbamqualitymetrics.cwl/picard_collectreadgroupbamqualitymetrics/reference"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.nameroot).*"
                    },
                    "id": "#picard_collectreadgroupbamqualitymetrics.cwl/picard_collectreadgroupbamqualitymetrics/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_collectwgsmetrics.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4500
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.15.0"
                }
            ],
            "baseCommand": [
                "java",
                "-Xms2000m",
                "-jar",
                "/picard.jar",
                "CollectWgsMetrics"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "INPUT=$(inputs.input_bam.path) VALIDATION_STRINGENCY=SILENT REFERENCE_SEQUENCE=$(inputs.reference.path) INCLUDE_BQ_HISTOGRAM=true INTERVALS=$(inputs.intervals.path) OUTPUT=$(inputs.input_bam.nameroot).wgs_metrics USE_FAST_ALGORITHM=true READ_LENGTH=250"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#picard_collectwgsmetrics.cwl/picard_collectwgsmetrics/input_bam"
                },
                {
                    "type": "File",
                    "id": "#picard_collectwgsmetrics.cwl/picard_collectwgsmetrics/intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#picard_collectwgsmetrics.cwl/picard_collectwgsmetrics/reference"
                }
            ],
            "outputs": [
                {
                    "id": "#picard_collectwgsmetrics.cwl/picard_collectwgsmetrics/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.nameroot).wgs_metrics"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_gatherbamfiles.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.8.3"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "baseCommand": [
                "java",
                "-Xms2000m",
                "-jar",
                "/picard.jar",
                "GatherBamFiles"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "OUTPUT=$(inputs.output_bam_basename).bam CREATE_INDEX=true CREATE_MD5_FILE=true"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "INPUT=",
                            "separate": false
                        }
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#picard_gatherbamfiles.cwl/picard_gatherbamfiles/input_bam"
                },
                {
                    "type": "string",
                    "id": "#picard_gatherbamfiles.cwl/picard_gatherbamfiles/output_bam_basename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bam"
                    },
                    "secondaryFiles": [
                        "^.bai",
                        ".md5"
                    ],
                    "id": "#picard_gatherbamfiles.cwl/picard_gatherbamfiles/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_intervallisttools.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.8.3"
                }
            ],
            "baseCommand": [
                "java",
                "-Xmx2000m",
                "-jar",
                "/picard.jar"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "IntervalListTools SCATTER_COUNT=50 SUBDIVISION_MODE=BALANCING_WITHOUT_INTERVAL_SUBDIVISION_WITH_OVERFLOW UNIQUE=true SORT=true BREAK_BANDS_AT_MULTIPLES_OF=1000000 INPUT=$(inputs.interval_list.path) OUTPUT=$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#picard_intervallisttools.cwl/picard_intervallisttools/interval_list"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "temp*/*.interval_list"
                    },
                    "id": "#picard_intervallisttools.cwl/picard_intervallisttools/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_markduplicates.cwl",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.8.3"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "baseCommand": [
                "java",
                "-Dsamjdk.compression_level=2",
                "-Xms4000m",
                "-jar",
                "/picard.jar",
                "MarkDuplicates"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "OUTPUT=$(inputs.base_file_name).aligned.unsorted.duplicates_marked.bam METRICS_FILE=metrics_filename VALIDATION_STRINGENCY=SILENT OPTICAL_DUPLICATE_PIXEL_DISTANCE=2500 ASSUME_SORT_ORDER=queryname"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#picard_markduplicates.cwl/picard_markduplicates/base_file_name"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "INPUT=",
                            "separate": false
                        }
                    },
                    "id": "#picard_markduplicates.cwl/picard_markduplicates/input_bams"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bam"
                    },
                    "id": "#picard_markduplicates.cwl/picard_markduplicates/output_markduplicates_bam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_mergevcfs.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 3000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.8.3"
                }
            ],
            "baseCommand": [
                "java",
                "-Xms2000m",
                "-jar",
                "/picard.jar",
                "MergeVcfs"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "OUTPUT=$(inputs.output_vcf_basename).g.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "INPUT=",
                            "separate": false
                        }
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_mergevcfs.cwl/picard_mergevcfs/input_vcf"
                },
                {
                    "type": "string",
                    "id": "#picard_mergevcfs.cwl/picard_mergevcfs/output_vcf_basename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_mergevcfs.cwl/picard_mergevcfs/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_revertsam.cwl",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.17.4"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [
                "java",
                "-Xms8000m",
                "-jar",
                "/picard.jar"
            ],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "RevertSam REFERENCE_SEQUENCE=$(inputs.reference.path) INPUT=$(inputs.input_bam.path) OUTPUT=$(runtime.outdir) OUTPUT_BY_READGROUP_FILE_FORMAT=bam SANITIZE=true MAX_DISCARD_FRACTION=0.005 ATTRIBUTE_TO_CLEAR=XT ATTRIBUTE_TO_CLEAR=XN ATTRIBUTE_TO_CLEAR=AS ATTRIBUTE_TO_CLEAR=OP SORT_ORDER=queryname RESTORE_ORIGINAL_QUALITIES=true REMOVE_DUPLICATE_INFORMATION=true REMOVE_ALIGNMENT_INFORMATION=true OUTPUT_BY_READGROUP=true"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#picard_revertsam.cwl/picard_revertsam/input_bam"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#picard_revertsam.cwl/picard_revertsam/reference"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.bam"
                    },
                    "id": "#picard_revertsam.cwl/picard_revertsam/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_sortsam.cwl",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.8.3"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "baseCommand": [
                "java",
                "-Xms4000m",
                "-jar",
                "/picard.jar"
            ],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "SortSam INPUT=$(inputs.input_bam.path) OUTPUT=$(inputs.base_file_name).aligned.duplicates_marked.sorted.bam SORT_ORDER=\"coordinate\" CREATE_INDEX=true CREATE_MD5_FILE=true MAX_RECORDS_IN_RAM=300000"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#picard_sortsam.cwl/picard_sortsam/base_file_name"
                },
                {
                    "type": "File",
                    "id": "#picard_sortsam.cwl/picard_sortsam/input_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.sorted.bam"
                    },
                    "secondaryFiles": [
                        "^.bai",
                        ".md5"
                    ],
                    "id": "#picard_sortsam.cwl/picard_sortsam/output_sorted_bam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#python_createsequencegroups.cwl",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/python:2.7.13"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "python",
                "-c"
            ],
            "arguments": [
                {
                    "position": 0,
                    "valueFrom": "def main():\n    with open(\"$(inputs.ref_dict.path)\", \"r\") as ref_dict_file:\n        sequence_tuple_list = []\n        longest_sequence = 0\n        for line in ref_dict_file:\n            if line.startswith(\"@SQ\"):\n                line_split = line.split(\"\\t\")\n                sequence_tuple_list.append((line_split[1].split(\"SN:\")[1], int(line_split[2].split(\"LN:\")[1])))\n        longest_sequence = sorted(sequence_tuple_list, key=lambda x: x[1], reverse=True)[0][1]\n    hg38_protection_tag = \":1+\"\n    tsv_string = sequence_tuple_list[0][0] + hg38_protection_tag\n    temp_size = sequence_tuple_list[0][1]\n    i = 0\n    for sequence_tuple in sequence_tuple_list[1:]:\n        if temp_size + sequence_tuple[1] <= longest_sequence:\n            temp_size += sequence_tuple[1]\n            tsv_string += \"\\n\" + sequence_tuple[0] + hg38_protection_tag\n        else:\n            i += 1\n            pad = \"{:0>2d}\".format(i)\n            tsv_file_name = \"sequence_grouping_\" + pad + \".intervals\"\n            with open(tsv_file_name, \"w\") as tsv_file:\n                tsv_file.write(tsv_string)\n                tsv_file.close()\n            tsv_string = sequence_tuple[0] + hg38_protection_tag\n            temp_size = sequence_tuple[1]\n    i += 1\n    pad = \"{:0>2d}\".format(i)\n    tsv_file_name = \"sequence_grouping_\" + pad + \".intervals\"\n    with open(tsv_file_name, \"w\") as tsv_file:\n        tsv_file.write(tsv_string)\n        tsv_file.close()\n\nif __name__ == \"__main__\":\n    main()"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#python_createsequencegroups.cwl/python_createsequencegroups/ref_dict"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.intervals"
                    },
                    "id": "#python_createsequencegroups.cwl/python_createsequencegroups/out_intervals"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#samtools_covert_to_cram.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/samtools:1.3.1"
                }
            ],
            "baseCommand": [
                "samtools",
                "view"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "-C -T $(inputs.reference.path) -o $(inputs.input_bam.nameroot).cram $(inputs.input_bam.path) && samtools index $(inputs.input_bam.nameroot).cram"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#samtools_covert_to_cram.cwl/samtools_convert_to_cram/input_bam"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#samtools_covert_to_cram.cwl/samtools_convert_to_cram/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.cram"
                    },
                    "secondaryFiles": [
                        ".crai"
                    ],
                    "id": "#samtools_covert_to_cram.cwl/samtools_convert_to_cram/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#verifybamid.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/verifybamid:1.0.2"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 5000,
                    "coresMin": 4
                }
            ],
            "baseCommand": [
                "/bin/VerifyBamID"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "--Verbose --NumPC 4 --Output $(inputs.output_basename) --BamFile $(inputs.input_bam.path) --Reference $(inputs.ref_fasta.path) --UDPath $(inputs.contamination_sites_ud.path) --MeanPath $(inputs.contamination_sites_mu.path) --BedPath $(inputs.contamination_sites_bed.path) 1>/dev/null"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#verifybamid.cwl/verifybamid/contamination_sites_bed"
                },
                {
                    "type": "File",
                    "id": "#verifybamid.cwl/verifybamid/contamination_sites_mu"
                },
                {
                    "type": "File",
                    "id": "#verifybamid.cwl/verifybamid/contamination_sites_ud"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#verifybamid.cwl/verifybamid/input_bam"
                },
                {
                    "type": "string",
                    "id": "#verifybamid.cwl/verifybamid/output_basename"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#verifybamid.cwl/verifybamid/ref_fasta"
                }
            ],
            "outputs": [
                {
                    "id": "#verifybamid.cwl/verifybamid/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.selfSM"
                    }
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#main",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/contamination_sites_bed"
                },
                {
                    "type": "File",
                    "id": "#main/contamination_sites_mu"
                },
                {
                    "type": "File",
                    "id": "#main/contamination_sites_ud"
                },
                {
                    "type": "File",
                    "id": "#main/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "id": "#main/indexed_reference_fasta"
                },
                {
                    "type": "File",
                    "id": "#main/input_bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/knownsites"
                },
                {
                    "type": "string",
                    "id": "#main/output_basename"
                },
                {
                    "type": "File",
                    "id": "#main/reference_dict"
                },
                {
                    "type": "File",
                    "id": "#main/wgs_calling_interval_list"
                },
                {
                    "type": "File",
                    "id": "#main/wgs_coverage_interval_list"
                },
                {
                    "type": "File",
                    "id": "#main/wgs_evaluation_interval_list"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/gatk_gatherbqsrreports/output",
                    "id": "#main/bqsr_report"
                },
                {
                    "type": "File",
                    "outputSource": "#main/picard_calculatereadgroupchecksum/output",
                    "id": "#main/calculate_readgroup_checksum"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/picard_collectaggregationmetrics/output",
                    "id": "#main/collect_collect_aggregation_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/picard_collectqualityyieldmetrics/output",
                    "id": "#main/collect_quality_yield_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/picard_collectreadgroupbamqualitymetrics/output",
                    "id": "#main/collect_readgroupbam_quality_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/picard_collectwgsmetrics/output",
                    "id": "#main/collect_wgs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/samtools_coverttocram/output",
                    "id": "#main/cram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/picard_gatherbamfiles/output",
                    "id": "#main/final_bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/picard_mergevcfs/output",
                    "id": "#main/gvcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/picard_collectgvcfcallingmetrics/output",
                    "id": "#main/picard_collect_gvcf_calling_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/verifybamid/output",
                    "id": "#main/verifybamid_output"
                }
            ],
            "steps": [
                {
                    "run": "#bwa_mem.cwl",
                    "in": [
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/bwa_mem/indexed_reference_fasta"
                        },
                        {
                            "source": "#main/picard_revertsam/output",
                            "id": "#main/bwa_mem/input_bam"
                        }
                    ],
                    "scatter": [
                        "#main/bwa_mem/input_bam"
                    ],
                    "out": [
                        "#main/bwa_mem/output"
                    ],
                    "id": "#main/bwa_mem"
                },
                {
                    "run": "#expression_checkcontamination.cwl",
                    "in": [
                        {
                            "source": "#main/verifybamid/output",
                            "id": "#main/checkcontamination/verifybamid_selfsm"
                        }
                    ],
                    "out": [
                        "#main/checkcontamination/contamination"
                    ],
                    "id": "#main/checkcontamination"
                },
                {
                    "run": "#python_createsequencegroups.cwl",
                    "in": [
                        {
                            "source": "#main/reference_dict",
                            "id": "#main/createsequencegrouping/ref_dict"
                        }
                    ],
                    "out": [
                        "#main/createsequencegrouping/out_intervals"
                    ],
                    "id": "#main/createsequencegrouping"
                },
                {
                    "run": "#gatk_applybqsr.cwl",
                    "in": [
                        {
                            "source": "#main/gatk_gatherbqsrreports/output",
                            "id": "#main/gatk_applybqsr/bqsr_report"
                        },
                        {
                            "source": "#main/picard_sortsam/output_sorted_bam",
                            "id": "#main/gatk_applybqsr/input_bam"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/gatk_applybqsr/reference"
                        },
                        {
                            "source": "#main/createsequencegrouping/out_intervals",
                            "id": "#main/gatk_applybqsr/sequence_interval"
                        }
                    ],
                    "scatter": [
                        "#main/gatk_applybqsr/sequence_interval"
                    ],
                    "out": [
                        "#main/gatk_applybqsr/recalibrated_bam"
                    ],
                    "id": "#main/gatk_applybqsr"
                },
                {
                    "run": "#gatk_baserecalibrator.cwl",
                    "in": [
                        {
                            "source": "#main/picard_sortsam/output_sorted_bam",
                            "id": "#main/gatk_baserecalibrator/input_bam"
                        },
                        {
                            "source": "#main/knownsites",
                            "id": "#main/gatk_baserecalibrator/knownsites"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/gatk_baserecalibrator/reference"
                        },
                        {
                            "source": "#main/createsequencegrouping/out_intervals",
                            "id": "#main/gatk_baserecalibrator/sequence_interval"
                        }
                    ],
                    "scatter": [
                        "#main/gatk_baserecalibrator/sequence_interval"
                    ],
                    "out": [
                        "#main/gatk_baserecalibrator/output"
                    ],
                    "id": "#main/gatk_baserecalibrator"
                },
                {
                    "run": "#gatk_gatherbqsrreports.cwl",
                    "in": [
                        {
                            "source": "#main/gatk_baserecalibrator/output",
                            "id": "#main/gatk_gatherbqsrreports/input_brsq_reports"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/gatk_gatherbqsrreports/output_basename"
                        }
                    ],
                    "out": [
                        "#main/gatk_gatherbqsrreports/output"
                    ],
                    "id": "#main/gatk_gatherbqsrreports"
                },
                {
                    "run": "#gatk_haplotypecaller.cwl",
                    "in": [
                        {
                            "source": "#main/checkcontamination/contamination",
                            "id": "#main/gatk_haplotypecaller/contamination"
                        },
                        {
                            "source": "#main/picard_gatherbamfiles/output",
                            "id": "#main/gatk_haplotypecaller/input_bam"
                        },
                        {
                            "source": "#main/picard_intervallisttools/output",
                            "id": "#main/gatk_haplotypecaller/interval_list"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/gatk_haplotypecaller/reference"
                        }
                    ],
                    "scatter": [
                        "#main/gatk_haplotypecaller/interval_list"
                    ],
                    "out": [
                        "#main/gatk_haplotypecaller/output"
                    ],
                    "id": "#main/gatk_haplotypecaller"
                },
                {
                    "run": "#gatk_validategvcf.cwl",
                    "in": [
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/gatk_validategvcf/dbsnp_vcf"
                        },
                        {
                            "source": "#main/picard_mergevcfs/output",
                            "id": "#main/gatk_validategvcf/input_vcf"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/gatk_validategvcf/reference"
                        },
                        {
                            "source": "#main/wgs_calling_interval_list",
                            "id": "#main/gatk_validategvcf/wgs_calling_interval_list"
                        }
                    ],
                    "out": [],
                    "id": "#main/gatk_validategvcf"
                },
                {
                    "run": "#picard_calculatereadgroupchecksum.cwl",
                    "in": [
                        {
                            "source": "#main/picard_gatherbamfiles/output",
                            "id": "#main/picard_calculatereadgroupchecksum/input_bam"
                        }
                    ],
                    "out": [
                        "#main/picard_calculatereadgroupchecksum/output"
                    ],
                    "id": "#main/picard_calculatereadgroupchecksum"
                },
                {
                    "run": "#picard_collectaggregationmetrics.cwl",
                    "in": [
                        {
                            "source": "#main/picard_gatherbamfiles/output",
                            "id": "#main/picard_collectaggregationmetrics/input_bam"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/picard_collectaggregationmetrics/reference"
                        }
                    ],
                    "out": [
                        "#main/picard_collectaggregationmetrics/output"
                    ],
                    "id": "#main/picard_collectaggregationmetrics"
                },
                {
                    "run": "#picard_collectgvcfcallingmetrics.cwl",
                    "in": [
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/picard_collectgvcfcallingmetrics/dbsnp_vcf"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/picard_collectgvcfcallingmetrics/final_gvcf_base_name"
                        },
                        {
                            "source": "#main/picard_mergevcfs/output",
                            "id": "#main/picard_collectgvcfcallingmetrics/input_vcf"
                        },
                        {
                            "source": "#main/reference_dict",
                            "id": "#main/picard_collectgvcfcallingmetrics/reference_dict"
                        },
                        {
                            "source": "#main/wgs_evaluation_interval_list",
                            "id": "#main/picard_collectgvcfcallingmetrics/wgs_evaluation_interval_list"
                        }
                    ],
                    "out": [
                        "#main/picard_collectgvcfcallingmetrics/output"
                    ],
                    "id": "#main/picard_collectgvcfcallingmetrics"
                },
                {
                    "run": "#picard_collectqualityyieldmetrics.cwl",
                    "in": [
                        {
                            "source": "#main/picard_revertsam/output",
                            "id": "#main/picard_collectqualityyieldmetrics/input_bam"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/picard_collectqualityyieldmetrics/output_basename"
                        }
                    ],
                    "scatter": [
                        "#main/picard_collectqualityyieldmetrics/input_bam"
                    ],
                    "out": [
                        "#main/picard_collectqualityyieldmetrics/output"
                    ],
                    "id": "#main/picard_collectqualityyieldmetrics"
                },
                {
                    "run": "#picard_collectreadgroupbamqualitymetrics.cwl",
                    "in": [
                        {
                            "source": "#main/picard_gatherbamfiles/output",
                            "id": "#main/picard_collectreadgroupbamqualitymetrics/input_bam"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/picard_collectreadgroupbamqualitymetrics/reference"
                        }
                    ],
                    "out": [
                        "#main/picard_collectreadgroupbamqualitymetrics/output"
                    ],
                    "id": "#main/picard_collectreadgroupbamqualitymetrics"
                },
                {
                    "run": "#picard_collectwgsmetrics.cwl",
                    "in": [
                        {
                            "source": "#main/picard_gatherbamfiles/output",
                            "id": "#main/picard_collectwgsmetrics/input_bam"
                        },
                        {
                            "source": "#main/wgs_coverage_interval_list",
                            "id": "#main/picard_collectwgsmetrics/intervals"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/picard_collectwgsmetrics/reference"
                        }
                    ],
                    "out": [
                        "#main/picard_collectwgsmetrics/output"
                    ],
                    "id": "#main/picard_collectwgsmetrics"
                },
                {
                    "run": "#picard_gatherbamfiles.cwl",
                    "in": [
                        {
                            "source": "#main/gatk_applybqsr/recalibrated_bam",
                            "id": "#main/picard_gatherbamfiles/input_bam"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/picard_gatherbamfiles/output_bam_basename"
                        }
                    ],
                    "out": [
                        "#main/picard_gatherbamfiles/output"
                    ],
                    "id": "#main/picard_gatherbamfiles"
                },
                {
                    "run": "#picard_intervallisttools.cwl",
                    "in": [
                        {
                            "source": "#main/wgs_calling_interval_list",
                            "id": "#main/picard_intervallisttools/interval_list"
                        }
                    ],
                    "out": [
                        "#main/picard_intervallisttools/output"
                    ],
                    "id": "#main/picard_intervallisttools"
                },
                {
                    "run": "#picard_markduplicates.cwl",
                    "in": [
                        {
                            "source": "#main/output_basename",
                            "id": "#main/picard_markduplicates/base_file_name"
                        },
                        {
                            "source": "#main/bwa_mem/output",
                            "id": "#main/picard_markduplicates/input_bams"
                        }
                    ],
                    "out": [
                        "#main/picard_markduplicates/output_markduplicates_bam"
                    ],
                    "id": "#main/picard_markduplicates"
                },
                {
                    "run": "#picard_mergevcfs.cwl",
                    "in": [
                        {
                            "source": "#main/gatk_haplotypecaller/output",
                            "id": "#main/picard_mergevcfs/input_vcf"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/picard_mergevcfs/output_vcf_basename"
                        }
                    ],
                    "out": [
                        "#main/picard_mergevcfs/output"
                    ],
                    "id": "#main/picard_mergevcfs"
                },
                {
                    "run": "#picard_revertsam.cwl",
                    "in": [
                        {
                            "source": "#main/input_bam",
                            "id": "#main/picard_revertsam/input_bam"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/picard_revertsam/reference"
                        }
                    ],
                    "out": [
                        "#main/picard_revertsam/output"
                    ],
                    "id": "#main/picard_revertsam"
                },
                {
                    "run": "#picard_sortsam.cwl",
                    "in": [
                        {
                            "source": "#main/output_basename",
                            "id": "#main/picard_sortsam/base_file_name"
                        },
                        {
                            "source": "#main/picard_markduplicates/output_markduplicates_bam",
                            "id": "#main/picard_sortsam/input_bam"
                        }
                    ],
                    "out": [
                        "#main/picard_sortsam/output_sorted_bam"
                    ],
                    "id": "#main/picard_sortsam"
                },
                {
                    "run": "#samtools_covert_to_cram.cwl",
                    "in": [
                        {
                            "source": "#main/picard_gatherbamfiles/output",
                            "id": "#main/samtools_coverttocram/input_bam"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/samtools_coverttocram/reference"
                        }
                    ],
                    "out": [
                        "#main/samtools_coverttocram/output"
                    ],
                    "id": "#main/samtools_coverttocram"
                },
                {
                    "run": "#verifybamid.cwl",
                    "in": [
                        {
                            "source": "#main/contamination_sites_bed",
                            "id": "#main/verifybamid/contamination_sites_bed"
                        },
                        {
                            "source": "#main/contamination_sites_mu",
                            "id": "#main/verifybamid/contamination_sites_mu"
                        },
                        {
                            "source": "#main/contamination_sites_ud",
                            "id": "#main/verifybamid/contamination_sites_ud"
                        },
                        {
                            "source": "#main/picard_sortsam/output_sorted_bam",
                            "id": "#main/verifybamid/input_bam"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/verifybamid/output_basename"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/verifybamid/ref_fasta"
                        }
                    ],
                    "out": [
                        "#main/verifybamid/output"
                    ],
                    "id": "#main/verifybamid"
                }
            ],
            "hints": [
                {
                    "class": "https://sevenbridges.comAWSInstanceType",
                    "value": "c5.9xlarge;ebs-gp2;768"
                },
                {
                    "class": "https://sevenbridges.commaxNumberOfParallelInstances",
                    "value": 4
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "sbg": "https://sevenbridges.com"
    }
}
